@@ -2,6 +2,7 @@ use std::error::Error;
 
 use reqwest::header::{HeaderMap, HeaderValue};
 
+use super::executor::RawExecResponse;
 use super::ExecResponse;
 use super::ExecResult;
 use super::Executor;
@@ -223,29 +224,44 @@ impl Client {
             .send()
             .await
         {
-            Ok(data) => match data.status() {
-                reqwest::StatusCode::OK => Ok(data.json::<ExecResponse>().await?),
-                _ => {
-                    let text = format!("{}: {}", data.status(), data.text().await?);
+            Ok(data) => {
+                let status = data.status();
 
-                    let exec_result = ExecResult {
-                        stdout: text.clone(),
-                        stderr: text.clone(),
-                        output: text,
-                        code: 1,
-                        signal: None,
-                    };
+                match status {
+                    reqwest::StatusCode::OK => {
+                        let response = data.json::<RawExecResponse>().await?;
 
-                    let exec_response = ExecResponse {
-                        language: executor.language.clone(),
-                        version: executor.version.clone(),
-                        run: exec_result,
-                        compile: None,
-                    };
+                        Ok(ExecResponse {
+                            language: response.language,
+                            version: response.version,
+                            run: response.run,
+                            compile: response.compile,
+                            status: status.as_u16(),
+                        })
+                    }
+                    _ => {
+                        let text = format!("{}: {}", data.status(), data.text().await?);
 
-                    Ok(exec_response)
+                        let exec_result = ExecResult {
+                            stdout: String::new(),
+                            stderr: text.clone(),
+                            output: text,
+                            code: 1,
+                            signal: None,
+                        };
+
+                        let exec_response = ExecResponse {
+                            language: executor.language.clone(),
+                            version: executor.version.clone(),
+                            run: exec_result,
+                            compile: None,
+                            status: status.as_u16(),
+                        };
+
+                        Ok(exec_response)
+                    }
                 }
-            },
+            }
             Err(e) => Err(Box::new(e)),
         }
     }
